pub enum StepMode {
Into,
Over {
start_depth: usize,
},
Out {
start_depth: usize,
},
}Expand description
How the stepping engine should behave after a resume.
Variants
Into
Stop at the very next line (descend into function calls).
Over
Stop at the next line at the same or shallower call depth.
Out
Stop after returning from the current function.