Module framework

Module framework 

Functions

collect_results
Collect structured test results from the lust framework.
register
Register the lust test framework into the given Lua VM.
run_tests
Run Lua test code with the lust framework pre-loaded.