register

Function register 

pub fn register(lua: &Lua) -> Result<(), Error>
Register the lust test framework into the given Lua VM.

After this call, lust is available as a global table with describe, it, expect, before, after, spy, and get_results.