Module framework
mlua_
probe_
core
0.1.2
Module framework
Module Items
Functions
In mlua_
probe_
core::
testing
mlua_probe_core
::
testing
Module
framework
Functions

collect_
results
Collect structured test results from the lust framework.
register
Register the lust test framework into the given Lua VM.
run_
tests
Run Lua test code with the lust framework pre-loaded.